set more off

use dataset, clear

replace treatyear = . if treatyear < 1999 // did not switch over this period

local j = 1

foreach y in dpropertytaxrevenue response_time {

	local mygraphs

	levelsof treatyear if treatyear > 1995, local(levels)
	foreach l of local levels {
		
		preserve		
		
			if `j' == 1 local mytitle "(a) Property Tax Growth (Percent)"
			if `j' == 2 local mytitle "(b) Response Times (Minutes)"
		
			count if treatyear == `l' & year == `l'
			local myn = r(N)
			
			collapse y=`y', by(year treatyear)
			
			su y if treatyear == `l' & year <= `l'
			local y1pre = r(mean)
			su y if treatyear == `l' & year > `l'
			local y1post = r(mean)
			
			su y if treatyear == . & year <= `l'
			local y0pre = r(mean)
			su y if treatyear == . & year > `l'
			local y0post = r(mean)
			
			local did = string((`y1post' - `y1pre') - (`y0post' - `y0pre'), "%20.02fc")
			
			#delimit;
			gr tw 
				(line y year if treatyear == `l', col(black) lwid(medthick))
				(line y year if treatyear == ., col(gray) lwid(thin))
				(scatteri `y1pre' 1995 `y1pre' `l', recast(line) col(black) lpat(dash) lwid(medthick))
				(scatteri `y1post' `l' `y1post' 2009, recast(line) col(black) lpat(dash) lwid(medthick))
				(scatteri `y0pre' 1995 `y0pre' `l', recast(line) col(gray) lpat(dash) lwid(thin))
				(scatteri `y0post' `l' `y0post' 2009, recast(line) col(gray) lpat(dash) lwid(thin))
				,
					title(`l', size(large))
					subtitle("(D=`did', N=`myn')", size(large))
					legend(off)
					name(g`l', replace)
					ytitle("")
					xtitle("")
					nodraw
					plotregion(style(none))
					ylab(, angle(horiz))
					xline(`l', lpat(solid) lcol(black) lwid(thin)) 
					;
			#delimit cr
			local mygraphs `mygraphs' g`l'
			
		restore
		
	}

	gr combine `mygraphs', title(`mytitle')
	
	if `j' == 1 {
		gr_edit .plotregion1.graph1.plotregion1.AddTextBox added_text editor 6.934497425609125 2003.564221875892
		gr_edit .plotregion1.graph1.plotregion1.added_text_new = 1
		gr_edit .plotregion1.graph1.plotregion1.added_text_rec = 1
		gr_edit .plotregion1.graph1.plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
		gr_edit .plotregion1.graph1.plotregion1.added_text[1].text = {}
		gr_edit .plotregion1.graph1.plotregion1.added_text[1].text.Arrpush Switched
		
		
		gr_edit .plotregion1.graph1.plotregion1.AddTextBox added_text editor 5.667708915637029 2001.94809675697
		gr_edit .plotregion1.graph1.plotregion1.added_text_new = 2
		gr_edit .plotregion1.graph1.plotregion1.added_text_rec = 2
		gr_edit .plotregion1.graph1.plotregion1.added_text[2].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
		gr_edit .plotregion1.graph1.plotregion1.added_text[2].style.editstyle color(gray) editcopy
		gr_edit .plotregion1.graph1.plotregion1.added_text[2].text = {}
		gr_edit .plotregion1.graph1.plotregion1.added_text[2].text.Arrpush Did not
		gr_edit .plotregion1.graph1.plotregion1.added_text[2].DragBy -.0345126708228746 -.9235000679556166
	}
	
	gr export "output/figure 2 `j'.eps", replace
	
	local j = `j' + 1

}
