set more off

use dataset, clear

su medfaminc2010, det
gen z = medfaminc2010 > r(p50)
replace z = . if mi(medfaminc2010)

save tmp, replace

foreach z in 0 1 {

	use tmp, clear

	keep if z == `z'

	gen timeto = year - treatyear

	local nlags = 5
	local nleads = 2
	gen D0 = timeto == 0
	forvalues j = 1(1)`nlags' {
		if `j' <= `nleads' gen D_`j' = timeto == -`j'
		gen D`j' = timeto == `j'
		if `j' == `nlags' replace D`j' = 1 if timeto > `nlags'
		if `j' == `nlags' replace D`j' = 0 if mi(timeto)
		local mylags `mylags' D`j'
		if `j' <= `nleads' local myleads `myleads' D_`j'
	} 

	foreach Y in dpropertytaxrevenue response_time {

		if "`Y'" == "dpropertytaxrevenue" local myylab -8(2)6
		if "`Y'" == "response_time" local myylab -.5(.5)2

		local templabel : var label `Y'

		preserve
			
			xtset district_id year
			eststo: areg `Y' `myleads' D0 `mylags' i.year, a(district_id) cl(district_id)
			gen index = _n - 10
			gen B = .
			gen UB = .
			gen LB = .
			forvalues j = -`nleads'(1)`nlags' {
				local k = abs(`j')
				if `j' < 0 {
					replace B = _b[D_`k'] if index == `j'
					replace UB = B + 1.96*_se[D_`k'] if index == `j'	
					replace LB = B - 1.96*_se[D_`k'] if index == `j'	
				}
				if `j' >=0 {
					replace B = _b[D`k'] if index == `j'
					replace UB = B + 1.96*_se[D`k'] if index == `j'	
					replace LB = B - 1.96*_se[D`k'] if index == `j'	
				}
			}
						
			keep if !mi(B)

			#delimit;

			gr tw 
				(line B index, col(black) lpat(solid) lwid(thick) msize(vlarge))
				(line UB LB index, col(black black) lpat(dash dash))
				,
					yline(0, lpat(solid) lwid(vthin))
					xline(0, lpat(solid) lwid(vthin))
					ylab(`myylab', angle(horiz))
					xlab(-`nleads'(1)`nlags')
					ytitle("")
					xtitle("")
					legend(off)
					plotregion(style(none))
					nodraw
					name(g`Y', replace)
					title("`templabel'")
					;
					
			#delimit cr
		
		restore
		
	}

	#delimit;

	gr combine 
		gdpropertytaxrevenue gresponse_time
		,
			l2title("Effect of Direct Democracy")
			b2title("Years since Direct Democracy")
			;
			
	#delimit cr

	gr export "output/figure 5 `z'.eps", replace

}

erase tmp.dta
