set more off

use dataset_notrim, clear

su dprop dtotalr dtotale

foreach x in dprop dtotalr dtotale {
	count if !mi(`x')
	local D = r(N)
	count if abs(`x') < 50
	di r(N)/`D'
}

gen B = .
gen UB = .
gen LB = .
gen index = _n
gen N = .

foreach y in dpropertytaxrevenue dtotalrevenue dtotalexpenditure {

	if "`y'" == "dpropertytaxrevenue" local mytitle "Property tax revenue growth"
	if "`y'" == "dtotalrevenue" local mytitle "Total revenue growth"
	if "`y'" == "dtotalexpenditure" local mytitle "Total expenditure growth"

	preserve
		
		forvalues x = 25(25)200 {
			count if abs(`y') < `x' & !mi(`y')
			local myn = r(N)
			count if !mi(dprop)
			local myd = r(N)
			reg `y' treat i.year if abs(dprop) < `x', a(gisid) cl(gisid)
			replace B = _b[treat] if index == `x'
			replace UB = _b[treat] + 1.96*_se[treat] if index == `x'
			replace LB = _b[treat] - 1.96*_se[treat] if index == `x'
			replace N = `myn' / `myd' if index == `x'
		}

		collapse B UB LB N, by(index)
		keep if !mi(B)
		
		#delimit;
		
		gr tw 
			(sc B index, col(black)) 
			(rspike UB LB index, col(black))
			(line N index, yaxis(2) col(black) lpat(dash))
			,
				yline(0)
				ylab(, angle(horiz))
				ylab(0(.25)1, axis(2) angle(horiz))
				xlab(25(25)200)
				ytitle("Effect of referendums")
				xtitle("Drop growth greater than")
				ytitle("Proportion of sample", axis(2))
				nodraw
				name(g`y', replace)
				plotregion(style(none))
				legend(off)
				title("`mytitle'")
				;
		
		#delimit cr
		
		local mygraphs `mygraphs' g`y'

	restore

}

gr combine `mygraphs', ycommon

gr export "output/figure A1.eps", replace
