set more off

use dataset, clear

gen timeto = year - treatyear
local nlags = 5
local nleads = 2
gen D0 = timeto == 0
forvalues j = 1(1)`nlags' {
	if `j' <= `nleads' gen D_`j' = timeto == -`j'
	gen D`j' = timeto == `j'
	if `j' == `nlags' replace D`j' = 1 if timeto > `nlags'
	if `j' == `nlags' replace D`j' = 0 if mi(timeto)
	local mylags `mylags' D`j'
	if `j' <= `nleads' local myleads `myleads' D_`j'
} 

gen mirev = mi(dprop)
gen mires = mi(response_time)
label variable mirev "Missing Revenue"
label variable mires "Missing Response Time"

foreach Y in mirev mires {

	local templabel : var label `Y'

	preserve

		areg `Y' `myleads' D0 `mylags' i.year, a(district_id) cl(district_id)
		 
		gen index = _n - 10
		gen B = .
		gen UB = .
		gen LB = .
		forvalues j = -`nleads'(1)`nlags' {
			local k = abs(`j')
			if `j' < 0 {
				replace B = _b[D_`k'] if index == `j'
				replace UB = B + 1.96*_se[D_`k'] if index == `j'	
				replace LB = B - 1.96*_se[D_`k'] if index == `j'	
			}
			if `j' >=0 {
				replace B = _b[D`k'] if index == `j'
				replace UB = B + 1.96*_se[D`k'] if index == `j'	
				replace LB = B - 1.96*_se[D`k'] if index == `j'	
			}
		}
		
		keep if !mi(B)

		#delimit;

		gr tw 
			(line B index, col(black) lpat(solid) lwid(thick))
			(line UB LB index, col(black black) lpat(shortdash shortdash))
			,
				yline(0, lpat(solid) lwid(vthin))
				xline(0, lpat(solid) lwid(vthin))
				ylab(, angle(horiz))
				xlab(-`nleads'(1)`nlags')
				ytitle("")
				xtitle("")
				legend(off)
				plotregion(style(none))
				nodraw
				name(g`Y', replace)
				title("`templabel'")
				;
				
		#delimit cr
	
	restore
	
}

#delimit;

gr combine 
	gmirev gmires
	,
		l2title("Effect of Direct Democracy")
		b2title("Years since Direct Democracy")
		;
		
#delimit cr
 
gr export "output/figure A3.eps", replace
