set more off

use dataset, clear

keep if year == 1995

local X lpopulation1990 pct65plus1990 pctwhite1990 medfaminc1990 demvoteshare  

*** rescale for readability ***

replace medfaminc1990 = medfaminc1990/1000
replace pct65plus1990 = pct65plus1990*100
replace pctwhite1990 = pctwhite1990*100

*** label ***

label variable lpopulation1990 "Population"
label variable pct65plus1990 "Share 65 and older"
label variable pctwhite1990 "Share white"
label variable medfaminc1990 "Median income"
label variable demvoteshare "Dem. vote share"

*** recoding for log scale ***

forvalues i = 0(1000)100000 {
	local log`i' = log(`i'+1)
}
local loghalf = log(.5 + 1)

*** make the plots ***

foreach x in `X' {

	local myxlab
	local mytext
	if "`x'" == "lpopulation1990" local myxlab xlab(`log1000' "1,000"  `log10000' "10,000" `log100000' "100,000")
	if "`x'" == "lpopulation1990" local mytext text(.4 `log45000' "Switched", col(black)) text(.18 `log80000' "Did not", col(gray))
	local mytitle : var label `x'

	#delimit

	gr tw
		(kdensity `x' if treated == 1, col(black) lwid(thick))
		(kdensity `x' if treated == 0, col(gray) lwid(medthick))
		,
			legend(off)
			nodraw
			name(g`x', replace)
			title("`mytitle'")
			plotregion(style(none))
			yscale(off)
			xtitle("")
			`myxlab'
			`mytext'
			;
		
	#delimit cr
	
	local mygraphs `mygraphs' g`x'
	
}

gr combine `mygraphs'

gr export "output/figure A6.eps", replace
