set more off

use dataset_press, clear

*** Get summary statistics by case ***

preserve
	replace Mentionedr = 0 if mi(Mentionedr)
	collapse Mentioned*, by(Case)
	su
restore

split Source, parse(";")
tab Source2
unique Source1
unique Source2

unique Case

*** Get number of hits by county ***

egen nhits = nvals(Case), by(county_name)

collapse nhits _cid x_c y_c, by(county_name)

replace nhits = 0 if mi(nhits)
replace county_name = "" if nhits == 0

replace nhits = 3 if nhits > 2

*** Make the figure ***

#delimit;

spmap
	nhits
		using "dataset_coords_counties"
		,
			id(_cid) 
			clmethod(unique)
			fcolor(gs15 gs13 gs11 gs9 gs7)
  			ndfcolor(white)
			ndocolor(white)
			ocolor(white white white white white white white white white)
 			legend(
				order(
					2 "0"
					3 "1"
					4 "2"
					5 "3 or more"
				)
				size(medium)
				symysize(large)
				symxsize(large)
				rowgap(0)
				
			)		
			label(label(county_name) xcoo(x_cc) ycoo(y_cc))
 			name(g1, replace)
			;

#delimit cr

gr export "output/figure A8.eps", replace
