set more off

use dataset_precincts, clear

keep if !mi(pctyes) & !mi(nfires2009)

su lmedfaminc

replace lmedfaminc = (lmed - r(min)) / (r(max) - r(min))

local X pctwhite lpopulation pct65plus

egen nfires2010 = rowtotal(nfires1995-nfires2009)
forvalues x = 1995(1)2009 {
	egen myden`x' = count(nfires`x'), by(precinct)
}
egen myden = rowtotal(myden1995-myden2009)
replace nfires2010 = nfires2010 / myden

gen index = _n + 1994

gen B = .
gen UB = .
gen LB = .
gen N = .
gen Y0 = .
gen Y1 = .
gen E = .

forvalues i = 1995(1)2010 {

	reg nfires`i' lmedfaminc, cl(district)
	replace B = _b[lmedfaminc] if index == `i'
	replace UB = B + 1.96*_se[lmedfaminc] if index == `i'
	replace LB = B - 1.96*_se[lmedfaminc] if index == `i'
	su nfires`i'
	replace N = r(N) if index == `i'
	preserve
		replace lmedfaminc = 0
		predict y0, xb
		replace lmedfaminc = 1
		predict y1, xb
		su y1
		local y1 = exp(`r(mean)')-1
		su y0
		local y0 = exp(`r(mean)')-1
	restore
	replace E = `y0'/`y1' if index == `i'
	replace Y0 = `y0' if index == `i'
	replace Y1 = `y1' if index == `i'
}


keep if !mi(B)

collapse B UB LB N Y0 Y1 E, by(index)
 
tostring E, replace format("%20.02fc") force

#delimit;

gr tw 
	(rspike UB LB index, col(black) lcol(gs10)) 
	(sc B index, col(black) mlab(E) mlabpos(12) mlabsize(vsmall) mfcol(white) msym(O))
	(line N index, yaxis(2) lpat(dash))
	,
		ylab(, angle(horiz))
		ylab(, angle(horiz) axis(2))
		ytitle("Relationship between fires and income")
		ytitle("Number of observations", axis(2))
		xtitle("Year of fires data")
		legend(off)
		xlab(1995(1)2009 2010 "Average", angle(45))
		yline(0)
		plotregion(style(none))
		xscale(range(1994 2011))
		;

#delimit cr

gr export "output/figure A9.eps", replace
