set more off

*** panel a ***

use dataset, clear

replace medfaminc2010 = log(medfaminc2010 + 1)
su medfaminc2010
replace medfaminc2010 = (medfaminc2010-r(min))/(r(max)-r(min))

su medfaminc2010, det
gen z = medfaminc2010 >= r(p50)
replace z = . if mi(medfaminc2010)
gen treatXincome = treat*medfaminc2010
label variable treatXincome "Treat X Income"

gen yearXincome = year * medfaminc2010

local X lpopulation pct65plus pctwhite medfaminc

eststo clear

eststo: areg dpropertytaxrevenue treat treatXincome  i.year year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X' year yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat treatXincome    i.year year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X'  year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X' year yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

esttab, keep(treat treatXincome) se compress

#delimit;

esttab
	using "output/table 3 a.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat treatXincome)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2)) se(par))
		mgroups(
			"Property Tax Growth (Percent)" "Response Times (Minutes)"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
			)
		)
		;		
		
#delimit cr

*** panel b ***

use dataset, clear

replace medfaminc2010 = log(medfaminc2010 + 1)
su medfaminc2010
replace medfaminc2010 = (medfaminc2010 -r(min))/(r(max)-r(min))

su medfaminc2010, det
gen z = medfaminc2010 >= r(p50)
replace z = . if mi(medfaminc2010)
replace medfaminc2010 = z

gen treatXincome = treat*medfaminc2010
label variable treatXincome "Treat X Income"

gen yearXincome = year * medfaminc2010

local X lpopulation pct65plus pctwhite medfaminc

eststo clear

eststo: areg dpropertytaxrevenue treat treatXincome  i.year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat treatXincome    i.year  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X'  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X'  yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

esttab, keep(treat treatXincome) se compress

#delimit;

esttab
	using "output/table 3 b.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat treatXincome)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2)) se(par))
		mgroups(
			"Property Tax Growth (Percent)" "Response Times (Minutes)"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
			)
		)
		;		
		
#delimit cr
