set more off

use dataset, clear

*** rescale for readability ***

replace medfaminc = medfaminc/1000
replace pct65plus = pct65plus*100
replace pctwhite = pctwhite*100

*** make missingness indicators ***

gen mirev = mi(dprop)
gen mires = mi(response_time)

*** label ***

label variable lpopulation "Population"
label variable pct65plus "Share 65 and older"
label variable pctwhite "Share white"
label variable medfaminc "Median income"
label variable treated "Switched"
label variable mirev "Missing revenue"
label variable mires "Missing response time"

local X treated lpopulation pct65plus pctwhite medfaminc

*** panel a ***

eststo clear

foreach y in rev res {

	qui {
		foreach x in `X' {
			eststo: reg `x' mi`y' i.year, cl(district_id)
			su `x' if mi`y' == 0
			estadd local sd0 = string(r(sd), "%20.02fc")
			estadd local sdiff = string(_b[mi`y']/r(sd), "%20.02fc")
		}
	}

}


#delimit;

esttab
	using "output/table A1 a.tex"
	,
		replace
		label
		collabels(none)
  		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))	
		drop(*year*)
 		stats(
			sd0 x sdiff x,
			label(
				"Standard deviation"
				"(non-missing)"
				"Standardized"
				"difference"
			)
			fmt(
				0
				0
				0
				0
			)
		)
		;
		
#delimit cr

*** panel b ***

local X lpopulation pct65plus pctwhite medfaminc

replace dprop = mirev
replace response_time = mires

eststo clear

eststo: areg dpropertytaxrevenue treat i.year, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat i.year `X', a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat i.year `X', a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat i.year, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat i.year `X', a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat i.year `X', a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

#delimit;

esttab
	using "output/table A1 b.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))
		mgroups(
			"Missing Property Tax Growth" "Missing Response Times"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype mymean,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
				"E[Y | Untreated]"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
				"%20.02fc"
			)
		)
		;
		
#delimit cr

