set more off

use dataset_elections, clear

unique gisid
unique gisid year election

tab status

gen anymissing = status != 1
gen nonemissing = status == 0
replace anymissing = . if mi(status)
replace nonemissing = . if mi(status)

local X lpopulation1990 pct65plus1990 pctwhite1990 medfaminc1990  

*** rescale for readability ***

replace medfaminc1990 = medfaminc1990/1000
replace pct65plus1990 = pct65plus1990*100
replace pctwhite1990 = pctwhite1990*100

*** label ***

label variable lpopulation1990 "Population"
label variable pct65plus1990 "Share 65 and older"
label variable pctwhite1990 "Share white"
label variable medfaminc1990 "Median income"
label variable anymissing "Any elections missing"

*** do the regressions ***

eststo clear
foreach x in `X' {
	eststo: reg `x' anymissing, cl(gisid)
	su `x' if anymissing == 0
	estadd local sd0 = string(r(sd), "%20.02fc")
	estadd local sdiff = string(_b[anymissing]/r(sd), "%20.02fc")
}

#delimit;

esttab
	using "output/table A2.tex"
	,
		replace
		label
		collabels(none)
  		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))	
  		stats(
			sd0 x sdiff x,
			label(
				"Standard deviation"
				"(none missing)"
				"Standardized"
				"difference"
			)
			fmt(
				0
				0
				0
				0
			)
		)
		;
		
#delimit cr
 
