set more off

use dataset, clear

keep if year == 1995

local X lpopulation1990 pct65plus1990 pctwhite1990 medfaminc1990 demvoteshare  

*** rescale for readability ***

replace medfaminc1990 = medfaminc1990/1000
replace pct65plus1990 = pct65plus1990*100
replace pctwhite1990 = pctwhite1990*100

*** label ***

label variable lpopulation1990 "Population"
label variable pct65plus1990 "Share 65 and older"
label variable pctwhite1990 "Share white"
label variable medfaminc1990 "Median income"
label variable demvoteshare "Dem. vote share"
label variable treated "Switched"

*** do the regressions ***

su `X' if treated == 0

eststo clear
 
foreach x in `X' {
	if "`x'" != "demvoteshare" eststo: reg `x' treated, robust
	if "`x'" == "demvoteshare" eststo: reg `x' treated, cl(county_name)
	su `x' if treated == 0
	estadd local sd0 = string(r(sd), "%20.02fc")
	estadd local sdiff = string(_b[treated]/r(sd), "%20.02fc")
}

#delimit;

esttab
	using "output/table A3.tex"
	,
		replace
		label
		collabels(none)
  		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))	
 		stats(
			sd0 x sdiff x,
			label(
				"Standard deviation"
				"(non-switchers)"
				"Standardized"
				"difference"
			)
			fmt(
				0
				0
				0
				0
			)
		)
		;
		
#delimit cr


	
	
 
