set more off

use dataset, clear

local X lpopulation pct65plus pctwhite medfaminc  

keep if !mi(nfires)

*** panel a ***

eststo clear
eststo: areg nfirespcp treat i.year, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
preserve
	replace treat = 0
	predict y0, xb
	replace treat = 1
	predict y1, xb
	su y1
	estadd scalar y1 = exp(`r(mean)')-1, replace
	su y0
	estadd scalar y0 = exp(`r(mean)')-1, replace
restore

estadd scalar mymean = exp(r(mean))-1
eststo: areg nfirespcp treat i.year `X', a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
preserve
	replace treat = 0
	predict y0, xb
	replace treat = 1
	predict y1, xb
	su y1
	estadd scalar y1 = exp(`r(mean)')-1, replace
	su y0
	estadd scalar y0 = exp(`r(mean)')-1, replace
restore

eststo: areg nfirespcp treat i.year `X', a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
preserve
	replace treat = 0
	predict y0, xb
	replace treat = 1
	predict y1, xb
	su y1
	estadd scalar y1 = exp(`r(mean)')-1, replace
	su y0
	estadd scalar y0 = exp(`r(mean)')-1, replace
restore

#delimit;

esttab
	using "output/table A5 a.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))
		mgroups(
			"Structure Fires (Logged)"
			,
				pattern(1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype y0 y1,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
				"E[Y | Untreated]"
				"E[Y | Treated]"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
				"%20.02fc"
			)
		)
		;
		
#delimit cr

*** panel b ***

local X lpopulation pct65plus pctwhite medfaminc nfires

eststo clear

eststo: areg dpropertytaxrevenue treat i.year, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat i.year `X', a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat i.year `X', a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat i.year, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat i.year `X', a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat i.year `X', a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

esttab, se keep(treat) compress

#delimit;

esttab
	using "output/table A5 b.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2) star) se(par))
		mgroups(
			"Property Tax Growth (Percent)" "Response Times (Minutes)"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype mymean,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
				"E[Y | Untreated]"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
				"%20.02fc"
			)
		)
		;		
		
#delimit cr

