set more off

*** panel a ***

use dataset, clear

egen nfirespcp2009m = mean(nfirespcp) if year == 2009, by(district_id)
egen nfirespcp2009 = mean(nfirespcp2009m), by(district_id)
su nfirespcp2009
replace nfirespcp2009 = (nfirespcp2009-r(min))/(r(max)-r(min))

su nfirespcp2009, det
gen z = nfirespcp2009 >= r(p50)
replace z = . if mi(nfirespcp2009)
gen treatXincome = treat*nfirespcp2009
label variable treatXincome "Treat X Incidence"

gen yearXincome = year * nfirespcp2009

local X lpopulation pct65plus pctwhite medfaminc

eststo clear

eststo: areg dpropertytaxrevenue treat treatXincome  i.year year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X' year yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat treatXincome    i.year year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year `X'  year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year `X' year yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

esttab, keep(treat treatXincome) se compress

#delimit;

esttab
	using "output/table A7 a.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat treatXincome)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2)) se(par))
		mgroups(
			"Property Tax Growth (Percent)" "Response Times (Minutes)"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
			)
		)
		;		
		
#delimit cr

*** panel b ***

use dataset, clear

egen nfirespcp2009m = mean(nfirespcp) if year == 2009, by(district_id)
egen nfirespcp2009 = mean(nfirespcp2009m), by(district_id)
su nfirespcp2009
replace nfirespcp2009 = (nfirespcp2009-r(min))/(r(max)-r(min))

su nfirespcp2009, det
gen z = nfirespcp2009 >= r(p50)
replace z = . if mi(nfirespcp2009)
replace nfirespcp2009 = z

gen treatXincome = treat*nfirespcp2009
label variable treatXincome "Treat X Incidence"

gen yearXincome = year * nfirespcp2009

local X lpopulation pct65plus pctwhite medfaminc

eststo clear

eststo: areg dpropertytaxrevenue treat treatXincome  i.year yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg dpropertytaxrevenue treat treatXincome   i.year `X'  yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su dpropertytaxrevenue if e(sample) & treat == 0
estadd scalar mymean = r(mean)

eststo: areg response_time treat treatXincome    i.year  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X'  yearXincome, a(district_id) cl(district_id)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "District"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)
eststo: areg response_time treat treatXincome i.year   `X'  yearXincome, a(district_id) cl(county_name)
estadd local yfe = "Y"
estadd local dfe = "Y"
estadd local setype = "County"
estadd local covariates = "Y"
su response_time if e(sample) & treat == 0
estadd scalar mymean = r(mean)

esttab, keep(treat treatXincome) se compress

#delimit;

esttab
	using "output/table A7 b.tex"
	,
		replace
		label
		collabels(none)
		nomtitles
		keep(treat treatXincome)
		booktabs
		width(\hsize)
		gap
		cells(b(fmt(2)) se(par))
		mgroups(
			"Property Tax Growth (Percent)" "Response Times (Minutes)"
			,
				pattern(1 0 0 1 0 0)
				prefix(\multicolumn{@span}{c}{) suffix(})
				span erepeat(\cmidrule(lr){@span})
		)		
		stats(
			N yfe dfe covariates setype,
			label(
				"Observations"
				"Year FE"
				"County FE"
				"Covariates"
				"Clustering"
			)
			fmt(
				"%20.00fc"
				0
				0
				0
				0
			)
		)
		;		
		
#delimit cr
